#!/usr/bin/env python
# coding: utf-8

import os
import matplotlib.pyplot as plt
import numpy as np
import dplume

def main():
    """
    Create boxplot with number of potentially observable CO2, CO and NO2
    plumes for Berlin with 1 to 6 satellites.
    """
    path = '/nas/smartcarb/output/'
    for tracer in ['CO2', 'NO2', 'CO']:
        filename = os.path.join(path, 'timeseries',
                                '%s_Berlin_plume_size.dat' % tracer)

        thr = {'CO2': 0.01, 'CO': 0.05, 'NO2': 0.30}[tracer]

        dplume.vis.plot_obs_per_month_and_nsat(filename, only_overlaps=True,
                                               cloud_thr=thr, bootstrap=True)

        if tracer == 'NO2':
            plt.ylim(0,18)
            plt.yticks(np.arange(18+1))
        else:
            plt.ylim(0,11)

        for ext in ['.png', '.pdf']:
            img_filename = os.path.join(
                path, 'figures',
                '%s_Berlin_plume_size%s' % (tracer, ext)
            )
            plt.savefig(img_filename)


if __name__ == '__main__':
    main()
